
Readme
~~~~~~

Anyvc is an abstraction library for all version control systems. Although
primarily a library, there is a command line tool (vc) to use with it.

Development
~~~~~~~~~~~

Main Repository::

    hg clone http://bitbucket.org/RonnyPfannschmidt/anyvc/

To easy_install the latest tip using::

    easy_install anyvc==dev

The link is http://bitbucket.org/RonnyPfannschmidt/anyvc/get/tip.zip#egg=anyvc-dev

Dependencies
~~~~~~~~~~~~~~
:mercurial: mercurial>=1.2
:subversion: subvertpy
:git: dulwich
:bazaar: bzr>=1.16
